import * as _solana_web3_js from '@solana/web3.js';
import { DevnetUrl, MainnetUrl, TestnetUrl, createSolanaRpc, createSolanaRpcSubscriptions, TransactionVersion, IInstruction, Address, TransactionSigner, Blockhash } from '@solana/web3.js';

/** Solana cluster moniker */
type SolanaClusterMoniker = "mainnet-beta" | "devnet" | "testnet" | "localnet";
type GenericUrl = string & {};
type ModifiedClusterUrl = DevnetUrl | MainnetUrl | TestnetUrl | GenericUrl;
type SolanaUrlOrMoniker = SolanaClusterMoniker | ModifiedClusterUrl;
type CreateSolanaClientArgs = {
    /** Full RPC URL (for a private RPC endpoint) or the Solana moniker (for a public RPC endpoint) */
    urlOrMoniker: URL | SolanaUrlOrMoniker;
    /** Configuration used to create the `rpc` client */
    rpcConfig?: Parameters<typeof createSolanaRpc>[1];
    /** Configuration used to create the `rpcSubscriptions` client */
    rpcSubscriptionsConfig?: Parameters<typeof createSolanaRpcSubscriptions>[1];
};
type CreateSolanaClientResult = {
    /** Newly created Solana RPC client  */
    rpc: ReturnType<typeof createSolanaRpc>;
    /** Newly created Solana RPC subscriptions client */
    rpcSubscriptions: ReturnType<typeof createSolanaRpcSubscriptions>;
};

type ExplorerLinkAccount = {
    address: string;
};
type ExplorerLinkTransaction = {
    transaction: string;
};
type ExplorerLinkBlock = {
    block: string;
};
/**
 * @param cluster - Default: `mainnet-beta`
 */
type GetExplorerLinkArgs = {
    cluster?: SolanaUrlOrMoniker;
} & (ExplorerLinkAccount | ExplorerLinkTransaction | ExplorerLinkBlock);

/** 1 billion lamports SOL */
declare const LAMPORTS_PER_SOL = 1000000000;

/**
 * Get a public Solana RPC endpoint for a cluster based on its moniker
 *
 * Note: These RPC URLs are rate limited and not suitable for production applications.
 */
declare function getPublicSolanaRpcUrl(cluster: SolanaClusterMoniker): string;
/**
 * Create a Solana `rpc` and `rpcSubscriptions` client
 */
declare function createSolanaClient({ urlOrMoniker, rpcConfig, rpcSubscriptionsConfig, }: CreateSolanaClientArgs): CreateSolanaClientResult;

/**
 * Craft a Solana Explorer link on any cluster
 */
declare function getExplorerLink(props: GetExplorerLinkArgs): URL;

type CreateTransactionInput = {
    /**
     * Transaction version
     * - `legacy` is commonly used
     * - `0` is needed for use with Address Lookup Tables
     * */
    version: TransactionVersion;
    /** List of instructions for this transaction */
    instructions: IInstruction[];
    /** Address or Signer that will pay transaction fees */
    feePayer: Address | TransactionSigner;
    /**
     * Latest blockhash (aka transaction lifetime) for this transaction to
     * accepted for execution on the Solana network
     * */
    latestBlockhash: Readonly<{
        blockhash: Blockhash;
        lastValidBlockHeight: bigint;
    }>;
};

/**
 * Simple interface for creating a Solana transaction
 */
declare function createTransaction({ version, feePayer, instructions, latestBlockhash, }: CreateTransactionInput): _solana_web3_js.TransactionMessageWithBlockhashLifetime & _solana_web3_js.ITransactionMessageWithFeePayer<string> & Omit<Readonly<{
    instructions: readonly _solana_web3_js.IInstruction<string, readonly _solana_web3_js.IAccountMeta<string>[]>[];
    version: "legacy";
}> | Readonly<{
    instructions: readonly _solana_web3_js.IInstruction<string, readonly (_solana_web3_js.IAccountLookupMeta<string, string> | _solana_web3_js.IAccountMeta<string>)[]>[];
    version: 0;
}>, "feePayer">;

export { type CreateSolanaClientArgs, type CreateSolanaClientResult, type GetExplorerLinkArgs, LAMPORTS_PER_SOL, type ModifiedClusterUrl, type SolanaClusterMoniker, type SolanaUrlOrMoniker, createSolanaClient, createTransaction, getExplorerLink, getPublicSolanaRpcUrl };
