'use strict';

var web3_js = require('@solana/web3.js');

// src/core/const.ts
var LAMPORTS_PER_SOL = 1e9;
function getPublicSolanaRpcUrl(cluster) {
  switch (cluster) {
    case "devnet":
      return "https://api.devnet.solana.com";
    case "testnet":
      return "https://api.testnet.solana.com";
    case "mainnet-beta":
      return "https://api.mainnet-beta.solana.com";
    case "localnet":
      return "http://127.0.0.1:8899";
    default:
      throw new Error("Invalid cluster moniker");
  }
}
function createSolanaClient({
  urlOrMoniker,
  rpcConfig,
  rpcSubscriptionsConfig
}) {
  if (typeof urlOrMoniker == "string") {
    try {
      urlOrMoniker = new URL(urlOrMoniker);
    } catch (err) {
      try {
        urlOrMoniker = new URL(
          getPublicSolanaRpcUrl(urlOrMoniker)
        );
      } catch (err2) {
        throw new Error("Invalid URL or cluster moniker");
      }
    }
  }
  const rpc = web3_js.createSolanaRpc(urlOrMoniker.toString(), rpcConfig);
  if (urlOrMoniker.protocol.endsWith("s")) urlOrMoniker.protocol = "wss";
  else urlOrMoniker.protocol = "ws";
  const rpcSubscriptions = web3_js.createSolanaRpcSubscriptions(
    urlOrMoniker.toString(),
    rpcSubscriptionsConfig
  );
  return {
    rpc,
    rpcSubscriptions
  };
}

// src/core/explorer.ts
function getExplorerLink(props) {
  let url = null;
  if (!props.cluster) props.cluster = "mainnet-beta";
  if ("address" in props) {
    url = new URL(`https://explorer.solana.com/address/${props.address}`);
  } else if ("transaction" in props) {
    url = new URL(`https://explorer.solana.com/tx/${props.transaction}`);
  } else if ("block" in props) {
    url = new URL(`https://explorer.solana.com/block/${props.block}`);
  }
  if (!url) throw new Error("Invalid Solana Explorer URL created");
  if (props.cluster !== "mainnet-beta") {
    if (props.cluster === "localnet") {
      url.searchParams.set("cluster", "custom");
      url.searchParams.set("customUrl", "http://localhost:8899");
    } else {
      url.searchParams.set("cluster", props.cluster);
    }
  }
  return url;
}
function createTransaction({
  version,
  feePayer,
  instructions,
  latestBlockhash
}) {
  return web3_js.pipe(
    web3_js.createTransactionMessage({ version }),
    (tx) => {
      if ("address" in feePayer && web3_js.isTransactionSigner(feePayer)) {
        return web3_js.setTransactionMessageFeePayerSigner(feePayer, tx);
      } else return web3_js.setTransactionMessageFeePayer(feePayer, tx);
    },
    (tx) => web3_js.setTransactionMessageLifetimeUsingBlockhash(latestBlockhash, tx),
    (tx) => web3_js.appendTransactionMessageInstructions(instructions, tx)
  );
}

exports.LAMPORTS_PER_SOL = LAMPORTS_PER_SOL;
exports.createSolanaClient = createSolanaClient;
exports.createTransaction = createTransaction;
exports.getExplorerLink = getExplorerLink;
exports.getPublicSolanaRpcUrl = getPublicSolanaRpcUrl;
//# sourceMappingURL=index.node.cjs.map
//# sourceMappingURL=index.node.cjs.map